@@ -26,13 +26,6 @@ except ImportError:
     _available_backends.remove('numba')
 
 
-__all__ = [
-    'compare_heartbeats',
-    'detect_heartbeats',
-    'rri_similarity',
-]
-
-
 # cache sos-filter created with scipy.signal.butter to reduce runtime
 _sos_filters = {}
 
@@ -54,7 +47,7 @@ def detect_heartbeats(ecg: np.ndarray, fs: float, backend: str = 'c') -> np.ndar
     - The signal might start during a peak, in which case it might have a
       relatively high initial amplitude, which will mess up threshold
       initialization. Therefore, everything until the first zero-crossing
-      is set to 0.
+      is set to zero.
     - The integration window is centered on the filtered signal, i.e. a
       peak in the filtered signal corresponds to a plateau in the
       integrated one, not a saddle in the rising edge. This lets the
@@ -100,7 +93,7 @@ def detect_heartbeats(ecg: np.ndarray, fs: float, backend: str = 'c') -> np.ndar
         backend = fallback
 
     # For short signals, creating the bandpass filter makes up a large part
-    # of the total runtime. Therefore the filter is cached to a global
+    # of the total runtime. Therefore the filter is cached in a global
     # variable.
     try:
         sos = _sos_filters[fs]
@@ -117,7 +110,7 @@ def detect_heartbeats(ecg: np.ndarray, fs: float, backend: str = 'c') -> np.ndar
     # filtering bidirectionally removes filter delay
     filtered_ecg = scipy.signal.sosfiltfilt(sos, ecg)
 
-    # Set everything until the first zero-crossing to 0. For efficiency,
+    # Set everything until the first zero-crossing to zero. For efficiency,
     # only the first 2 seconds are checked.
     signal_start = np.where(np.diff(np.signbit(filtered_ecg[:int(2 * fs)])))[0][0] + 1
     filtered_ecg[:signal_start] = 0
@@ -230,7 +223,7 @@ def rri_similarity(
     RR intervals are calculated from detected and annotated heartbeat
     indices. The RR time series is then resampled to frequency
     `fs_resample` in the timespan common to both detection and annotation.
-    Pearson's and Spearman's correlation coefficient as well as the root
+    Pearson's and Spearman's correlation coefficients as well as the root
     mean square error are returned.
 
     Parameters
@@ -298,11 +291,11 @@ def _squared_moving_integration_py(x: np.ndarray, window_length: int) -> np.ndar
     sum = 0
 
     # the integration window is centered on the original signal, for even
-    # window_length the behaviour of np.convolve with a constant window of
+    # window_length the behavior of np.convolve with a constant window of
     # even length is replicated (i.e the window is off-center to the left)
     window_length_half = (window_length + 1) // 2
 
-    # during the first `window_length/2` samples, there's no output, since
+    # during the first `window_length/2` samples there is no output since
     # the integration window's center would be at a negative index of the
     # input
     for i in range(window_length_half):
@@ -348,7 +341,7 @@ def _thresholding_py(
     -------
     np.ndarray
         Array containing `1` for every sample in `filtered_ecg` identified
-        as a heartbeat (i.e. R-peak).
+        as a heartbeat.
     """
     signal_len = len(filtered_ecg)
     beat_mask = np.zeros_like(filtered_ecg)  # numba can't work with dtype=bool
@@ -369,47 +362,34 @@ def _thresholding_py(
     # respectively. Therefore, SPKF/SPKI are assumed to be the maximum
     # values of the filtered/integrated signal during the learning phase.
     # Accordingly, NPKF/NPKI are initialized to the mean values during the
-    # learning phase.
-    learning_phase_samples = int(2 * fs)  # 2 seconds
-    filtered_ecg_maximum = 0
-    filtered_ecg_sum = 0
-    integrated_ecg_maximum = 0
-    integrated_ecg_sum = 0
-    for i in range(learning_phase_samples):
-        if (filtered_ecg[i] > filtered_ecg_maximum):
-            filtered_ecg_maximum = filtered_ecg[i]
-        if (integrated_ecg[i] > integrated_ecg_maximum):
-            integrated_ecg_maximum = integrated_ecg[i]
-        filtered_ecg_sum += filtered_ecg[i]
-        integrated_ecg_sum += integrated_ecg[i]
-
-    SPKF = filtered_ecg_maximum
-    NPKF = filtered_ecg_sum / learning_phase_samples
-    SPKI = integrated_ecg_maximum
-    NPKI = integrated_ecg_sum / learning_phase_samples
+    # first two seconds.
+    SPKF = np.max(filtered_ecg[:int(2 * fs)])
+    NPKF = np.mean(filtered_ecg[:int(2 * fs)])
+    SPKI = np.max(integrated_ecg[:int(2 * fs)])
+    NPKI = np.mean(integrated_ecg[:int(2 * fs)])
     threshold_I1 = NPKI + 0.25 * (SPKI - NPKI)
     threshold_F1 = NPKF + 0.25 * (SPKF - NPKF)
 
     # According to the original paper, `RR AVERAGE2` is the average of the
-    # last 8 RR-intervals, that lie in a certain interval. In the worst
-    # case, this requires going back to the very first RR-interval.
-    # Therefore, all RR-intervals are stored. As the algorithm enforces a
-    # refractory period, there can't be more than $signal_len /
-    # refractory_samples$ heartbeats.
+    # last 8 RR intervals that lie in a certain interval. In the worst
+    # case, this requires going back to the very first RR interval.
+    # Therefore, all RR intervals are stored. As the algorithm enforces a
+    # refractory period, the maximum number of heartbeats is equal to
+    # signal_len / refractory_samples.
     RR_intervals = np.zeros(signal_len//REFRACTORY_SAMPLES)
 
     # tracking the number of peaks found is required to calculate the
-    # average RR-intervals correctly during the first 8 beats. Also needed
-    # for access to RR_intervals
+    # average RR intervals correctly during the first 8 beats (also needed
+    # for access to RR_intervals)
     num_peaks_found = 0
 
     RR_missed_limit = None
 
-    # In case a searchback was unsuccessful, no new searchback will be
-    # performed until another signal peak has been found regularly.
+    # in case a searchback was unsuccessful, no new searchback will be
+    # performed until another signal peak has been found regularly
     do_searchback = True
 
-    # initialize so searchback before any peak was detected works
+    # initialize, so searchback before any peak has been detected works
     peak_index = -REFRACTORY_SAMPLES + 1
     previous_peak_index = -REFRACTORY_SAMPLES + 1
 
@@ -428,38 +408,37 @@ def _thresholding_py(
         # half. The peak with highest amplitude between 200ms (i.e. the
         # refractory period) after the previous detected peak and the
         # current index is considered as a peak candidate.
-        # Modifications compared to Pan&Tompkins' original method:
-        # - The original paper states that a searchback-peak's amplitude
+        # Modifications compared to Pan & Tompkins' original method:
+        # - The original paper states that a searchback peak's amplitude
         #   has to be between the original threshold and the reduced one.
-        #   The situation can arise, that this is the case for the
-        #   filtered signal, but not for the integrated one (if the raw
-        #   signal amplitude is suddenly considerably lower). Therefore,
-        #   this implementation requires both of the signals
-        #   (filtered+integrated) to be above the reduced threshold, but
-        #   only one of them to be below the original threshold.
+        #   It can happen that this is the case for the filtered signal,
+        #   but not for the integrated one (if the raw signal amplitude is
+        #   suddenly considerably lower). Therefore, this implementation
+        #   requires both signals (filtered and integrated) to be above
+        #   the reduced threshold, but only one of them to be below the
+        #   original threshold.
         # - No further steps are specified for the case that no peak is
         #   found during searchback. Since a searchback is triggered
-        #   because (physiologically) there _has_ to be a heartbeat during
+        #   because (physiologically) there has to be a heartbeat during
         #   the searchback interval, this implementation repeats the
         #   process with further reduced thresholds. Up to 16 searchback
-        #   runs are performed, each time the thresholds are futher
-        #   reduced by 1/2. Giving a hard limit of 16 runs prevents
-        #   getting into an endless loop in case there's really just
-        #   noise.
+        #   runs are performed, each time the thresholds are further
+        #   reduced by 1/2. A hard limit of 16 runs avoids an endless loop
+        #   in case there's really just noise.
         # - Since the criterion for triggering a searchback is based on
-        #   the average RR-interval, in the original form this could only
+        #   the average RR interval, in the original form this could only
         #   happen after at least two detected heartbeats. An
         #   exceptionally large peak during the first learning phase can
         #   throw the initial thresholds off, so peaks at the beginning
         #   are ignored - which in turn invalidates learning phase 2.
         #   Therefore, in addition to the original searchback criterion
-        #   (no peak during 1.66*"the average RR interval"), a searchback
-        #   is triggered in two cases: 1) if there's no peak during the
-        #   first second and 2) if there's no peak 1.5s after the first
-        #   peak.
+        #   (no peak during 1.66 * "the average RR interval"), a
+        #   searchback is triggered in two cases: (1) if there is no peak
+        #   during the first second, and (2) if there is no peak 1.5s
+        #   after the first peak.
         if ((num_peaks_found > 1 and index - previous_peak_index > RR_missed_limit and do_searchback) or  # original criterion  # noqa: E501
-                (num_peaks_found == 0 and index > fs) or                             # 1)
-                (num_peaks_found == 1 and index - previous_peak_index > 1.5 * fs)):  # 2)
+                (num_peaks_found == 0 and index > fs) or                             # (1)
+                (num_peaks_found == 1 and index - previous_peak_index > 1.5 * fs)):  # (2)
 
             for i in range(1, 16):
                 found_a_candidate = False
@@ -472,13 +451,13 @@ def _thresholding_py(
                 while searchback_index < index:
                     PEAKF = filtered_ecg[searchback_index]
                     if PEAKF > filtered_ecg[searchback_index + 1]:
-                        # next one's lower
+                        # next one is lower
                         if PEAKF > filtered_ecg[searchback_index - 1]:
-                            # it's a peak
+                            # it is a peak
                             PEAKI = integrated_ecg[searchback_index]
-                            # One signal is between the reduced and
+                            # one signal is between the reduced and
                             # original threshold, the other one above the
-                            # reduced threshold.
+                            # reduced threshold
                             if ((threshold_F1 / searchback_divisor < PEAKF and PEAKF < threshold_F1 and threshold_I1 / searchback_divisor < PEAKI) or  # noqa: E501
                                     (threshold_I1 / searchback_divisor < PEAKI and PEAKI < threshold_I1 and threshold_F1 / searchback_divisor < PEAKF)):   # noqa: E501
                                 if PEAKF > best_candidate_amplitude:
@@ -487,7 +466,7 @@ def _thresholding_py(
                                     best_candidate_amplitude = filtered_ecg[searchback_index]  # noqa: E501
                                     found_a_candidate = True
 
-                        # the amplitude of the next sample is lower -> it
+                        # the amplitude of the next sample is lower, so it
                         # can't be a peak -> skip it
                         searchback_index += 1
 
@@ -499,8 +478,8 @@ def _thresholding_py(
                     signal_peak_found = True
                     peak_index = best_searchback_index
 
-                    # Don't perform a searchback until the next signal
-                    # peak has been found to avoid endless loops.
+                    # don't perform a searchback until the next signal
+                    # peak has been found to avoid endless loops
                     do_searchback = False
                     break
 
@@ -513,7 +492,7 @@ def _thresholding_py(
                     # Both the filtered and the integrated signal are
                     # above their respective thresholds. Thus the current
                     # peak is classified as a signal peak and the running
-                    # estimates SPKF and SPKI are updated
+                    # estimates SPKF and SPKI are updated.
                     SPKF = 0.125 * PEAKF + 0.875 * SPKF
                     SPKI = 0.125 * PEAKI + 0.875 * SPKI
 
@@ -527,22 +506,22 @@ def _thresholding_py(
             # if-clauses for this block.
             index += 1
 
-        # Calculating the RR-interval and comparing slopes only makes
-        # sense, if there has already been a signal peak in the past,
+        # Calculating the RR interval and comparing slopes only makes
+        # sense if there has already been a signal peak in the past.
         if signal_peak_found and num_peaks_found > 0:
             RR = peak_index - previous_peak_index
 
             # ------------------------------------------------------------
-            # T-Wave Identification
+            # T Wave Identification
             # ------------------------------------------------------------
-            # "When an RI interval is less than 360 ms (it must be greater
+            # "When an RR interval is less than 360 ms (it must be greater
             # than the 200 ms latency), a judgment is made to determine
             # whether the current QRS complex has been correctly
             # identified or whether it is really a T wave. If the maximal
             # slope that occurs during this waveform is less than half
             # that of the QRS waveform that preceded it, it is identified
-            # to be a Twave; otherwise, it is called a QRS complex." (from
-            # Pan&Tompkins, 1985)
+            # to be a T wave; otherwise, it is called a QRS complex."
+            # (from Pan & Tompkins, 1985)
             if RR < T_WAVE_WINDOW:
                 reverse_index = peak_index
                 max_slope_in_this_peak = -1
@@ -569,22 +548,22 @@ def _thresholding_py(
                     reverse_index -= 1
 
                 if max_slope_in_this_peak < max_slope_in_previous_peak / 2.0:
-                    # based on the slope, this peak should be a T-Wave
+                    # based on the slope, this peak should be a T wave
                     signal_peak_found = False
                     noise_peak_found = True
 
         if signal_peak_found:
-            # What we know so far: we're at a local maximum, both
-            # thresholds are exceeded and it's not a T-Wave. Thus, the
+            # What we know so far: we are at a local maximum, both
+            # thresholds are exceeded and it is not a T wave. Thus, the
             # current sample can be considered as a "signal peak" and the
-            # adaptive are updated.
+            # adaptive thresholds are updated.
             num_peaks_found += 1
             beat_mask[peak_index] = 1
 
             threshold_I1 = NPKI + 0.25 * (SPKI - NPKI)
             threshold_F1 = NPKF + 0.25 * (SPKF - NPKF)
 
-            # Calculating RR-averages only makes sense once 2 peaks have
+            # calculating RR averages only makes sense once 2 peaks have
             # been found
             if num_peaks_found > 1:
                 RR_intervals[num_peaks_found] = peak_index - previous_peak_index
@@ -593,8 +572,8 @@ def _thresholding_py(
                 # Learning phase 2
                 # --------------------------------------------------------
                 # "Learning phase 2 requires two heartbeats to initialize
-                # RR -interval average and RR-interval limit values."
-                # (from Pan&Tompkins, 1985)
+                # RR interval average and RR interval limit values."
+                # (from Pan & Tompkins, 1985)
                 if num_peaks_found == 2:
                     RR_low_limit = 0.92 * RR_intervals[num_peaks_found]
                     RR_high_limit = 1.16 * RR_intervals[num_peaks_found]
@@ -603,7 +582,7 @@ def _thresholding_py(
                 # RR Average 1 / RR Average 2
                 # --------------------------------------------------------
                 # RR Average 2 is the average of the 8 most recent RR
-                # intervals, which fell between RR_low_limit and
+                # intervals which fell between RR_low_limit and
                 # RR_high_limit. In case of a regular heart rate, this
                 # equals RR Average 1 (the average over the 8 most recent
                 # RR intervals, independent of any limits). Therefore, RR
@@ -637,7 +616,7 @@ def _thresholding_py(
             # makes sense.
             do_searchback = True
 
-            # previous peak index is required to calculate the RR-interval
+            # previous peak index is required to calculate the RR interval
             previous_peak_index = peak_index
 
             # no peak can happen during the refractory period, so skip it
@@ -651,7 +630,7 @@ def _thresholding_py(
 
         index += 1
 
-    # Return an array containing `1` at each beat-position, `0` elsewhere.
+    # return an array containing `1`s at beat positions and `0`s elsewhere
     return beat_mask
 
 
